==> AxolotlClient-3.1.6%2B1.21.10-sources.jar: io/github/axolotlclient/mixin/TntEntityRendererMixin.java <==
/*
 * Copyright © 2024 moehreag <moehreag@gmail.com> & Contributors
 *
 * This file is part of AxolotlClient.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * For more information, see the LICENSE file.
 */

package io.github.axolotlclient.mixin;

import io.github.axolotlclient.modules.tnttime.TntTime;
import net.minecraft.class_10075;
import net.minecraft.class_11659;
import net.minecraft.class_12075;
import net.minecraft.class_1541;
import net.minecraft.class_243;
import net.minecraft.class_4587;
import net.minecraft.class_5617;
import net.minecraft.class_897;
import net.minecraft.class_956;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_956.class)
public abstract class TntEntityRendererMixin extends class_897<class_1541, class_10075> {

	protected TntEntityRendererMixin(class_5617.class_5618 ctx) {
		super(ctx);
	}

	@Inject(
		method = "submit(Lnet/minecraft/client/renderer/entity/state/TntRenderState;Lcom/mojang/blaze3d/vertex/PoseStack;Lnet/minecraft/client/renderer/SubmitNodeCollector;Lnet/minecraft/client/renderer/state/CameraRenderState;)V",
		at = @At(value = "TAIL"))
	private void axolotlclient$render(class_10075 tntRenderState, class_4587 poseStack, class_11659 submitNodeCollector, class_12075 cameraRenderState, CallbackInfo ci) {
		if (TntTime.getInstance().enabled.get()) {
			poseStack.method_22903();
			if (tntRenderState.field_53337 != null) {
				poseStack.method_22904(0, 0.25, 0);
			}
			class_243 prevAttachment = tntRenderState.field_53338;
			if (prevAttachment == null) {
				tntRenderState.field_53338 = new class_243(0, 1, 0);
			}
			submitNodeCollector.method_73482(
				poseStack,
				tntRenderState.field_53338,
				0,
				TntTime.getInstance().getFuseTime(tntRenderState.field_53596),
				!tntRenderState.field_53334,
				tntRenderState.field_61820,
				tntRenderState.field_53332,
				cameraRenderState
			);
			tntRenderState.field_53338 = prevAttachment;
			poseStack.method_22909();
		}
	}
}

==> AxolotlClient-3.1.7%2B1.21.11-sources.jar: io/github/axolotlclient/mixin/TntEntityRendererMixin.java <==
/*
 * Copyright © 2024 moehreag <moehreag@gmail.com> & Contributors
 *
 * This file is part of AxolotlClient.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * For more information, see the LICENSE file.
 */

package io.github.axolotlclient.mixin;

import io.github.axolotlclient.modules.tnttime.TntTime;
import net.minecraft.class_10075;
import net.minecraft.class_11659;
import net.minecraft.class_12075;
import net.minecraft.class_1541;
import net.minecraft.class_243;
import net.minecraft.class_2561;
import net.minecraft.class_4587;
import net.minecraft.class_5617;
import net.minecraft.class_897;
import net.minecraft.class_956;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_956.class)
public abstract class TntEntityRendererMixin extends class_897<class_1541, class_10075> {

	protected TntEntityRendererMixin(class_5617.class_5618 ctx) {
		super(ctx);
	}

	@Inject(
		method = "submit(Lnet/minecraft/client/renderer/entity/state/TntRenderState;Lcom/mojang/blaze3d/vertex/PoseStack;Lnet/minecraft/client/renderer/SubmitNodeCollector;Lnet/minecraft/client/renderer/state/CameraRenderState;)V",
		at = @At(value = "TAIL"))
	private void axolotlclient$render(class_10075 tntRenderState, class_4587 poseStack, class_11659 submitNodeCollector, class_12075 cameraRenderState, CallbackInfo ci) {
		if (TntTime.getInstance().enabled.get()) {
			poseStack.method_22903();
			if (tntRenderState.field_53337 != null) {
				poseStack.method_22904(0, 0.25, 0);
			}
			class_243 prevAttachment = tntRenderState.field_53338;
			if (prevAttachment == null) {
				tntRenderState.field_53338 = new class_243(0, 1, 0);
			}
			submitNodeCollector.method_73482(
				poseStack,
				tntRenderState.field_53338,
				0,
				(class_2561) TntTime.getInstance().getFuseTime(tntRenderState.field_53596),
				!tntRenderState.field_53334,
				tntRenderState.field_61820,
				tntRenderState.field_53332,
				cameraRenderState
			);
			tntRenderState.field_53338 = prevAttachment;
			poseStack.method_22909();
		}
	}
}
